@@ -6,7 +6,11 @@
 #
 # ----------
 
+from .paths import Path
 from .nodes import (
-    Path,
+    NodeType,
     NodeInfo, DirectoryInfo, FileInfo,
 )
+from .serialize import (
+    FormatNotFoundError, SerializeError
+)
